@@ -192,6 +192,11 @@ public final class JLatexMath extends ExampleFrame {
             }
         }
 
+	@Override
+	public boolean is2DView() {
+	    return false;
+	}
+
         @Override
         public void dataChanged(final LatexCompositor compositor) {
             compositor.textArea.setBackground(Color.RED);
