@@ -120,6 +120,11 @@ public final class MilkDrop extends ExampleFrame {
             rulerDrawer.draw(dt, getZRulerModel());
         }
 
+	@Override
+	public boolean is2DView() {
+	    return false;
+	}
+
         /**
          * X ruler model getter.
          * @return the X ruler model.
