@@ -25,6 +25,7 @@ import java.util.List;
 import org.scilab.forge.scirenderer.DrawingTools;
 import org.scilab.forge.scirenderer.buffers.ElementsBuffer;
 import org.scilab.forge.scirenderer.clipping.ClippingPlane;
+import org.scilab.forge.scirenderer.implementation.g2d.G2DCanvas;
 import org.scilab.forge.scirenderer.implementation.g2d.buffers.G2DElementsBuffer;
 import org.scilab.forge.scirenderer.implementation.g2d.texture.G2DTextureDrawingTools;
 import org.scilab.forge.scirenderer.implementation.g2d.texture.G2DTextureManager;
@@ -49,13 +50,15 @@ public class Motor3D {
     private Graphics2D g2d;
     private Dimension dim;
     private G2DTextureDrawingTools textureDrawingTools;
+    private G2DCanvas canvas;
 
     /**
      * Default constructor
      * @param g2d a Graphics2D object where to draw
      * @param dim the graphic dimensions
      */
-    public Motor3D(Graphics2D g2d, Dimension dim) {
+    public Motor3D(G2DCanvas canvas, Graphics2D g2d, Dimension dim) {
+	this.canvas = canvas;
         this.g2d = g2d;
         this.dim = dim;
         this.textureDrawingTools = new G2DTextureDrawingTools(g2d);
@@ -63,6 +66,10 @@ public class Motor3D {
         //g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
     }
 
+    public boolean is2DView() {
+	return canvas.getMainDrawer().is2DView();
+    }
+
     public void setClippingPlanes(List<ClippingPlane> clippingPlanes) {
         Scene.setClippingPlanes(clippingPlanes);
     }
@@ -116,6 +123,8 @@ public class Motor3D {
      */
     public void draw() {
         Scene.drawRoot(g2d);
+        Scene.clear();
+        G2DTextureManager.clear();
     }
 
     public void drawTexture(DrawingTools drawingTools, BufferedImage image, Texture texture) {
@@ -180,7 +189,7 @@ public class Motor3D {
         if (positionsBuffer.hasArray()) {
             buffer = positionsBuffer.array();
         } else {
-            buffer = new float[positionsBuffer.capacity()];
+            buffer = new float[positionsBuffer.limit()];
             positionsBuffer.get(buffer);
         }
         Vector3d[] verticesArray = getMultiVectors(buffer, transf, false);
@@ -208,10 +217,10 @@ public class Motor3D {
         if (normal != null) {
             //normal = transf.projectDirection(normal);
             if ((mode == FaceCullingMode.CW && normal.getZ() > 0) || (mode == FaceCullingMode.CCW && normal.getZ() < 0) || mode == FaceCullingMode.BOTH) {
-                Scene.addToRoot(tri);
+                Scene.addToRoot(is2DView(), tri);
             }
         } else {
-            Scene.addToRoot(tri);
+            Scene.addToRoot(is2DView(), tri);
         }
     }
 
@@ -220,11 +229,11 @@ public class Motor3D {
      * @param s the segment to add
      */
     private void add(Segment s) {
-        Scene.addToRoot(s);
+        Scene.addToRoot(is2DView(), s);
     }
 
     private void add(SpritedRectangle sprite) {
-        Scene.addToRoot(sprite);
+        Scene.addToRoot(is2DView(), sprite);
     }
 
     /**
@@ -245,7 +254,7 @@ public class Motor3D {
         if (vertices.hasArray()) {
             buffer = vertices.array();
         } else {
-            buffer = new float[vertices.capacity()];
+            buffer = new float[vertices.limit()];
             vertices.get(buffer);
         }
         verticesArray = getMultiVectors(buffer, transf, false);
@@ -255,20 +264,21 @@ public class Motor3D {
             if (colors.hasArray()) {
                 buffer = colors.array();
             } else {
-                buffer = new float[colors.capacity()];
+                buffer = new float[colors.limit()];
                 colors.get(buffer);
             }
             colorsArray = getMultiColors(buffer);
         } else {
-            colorsArray = new Color[vertices.capacity()];
+            colorsArray = new Color[vertices.limit()];
             Arrays.fill(colorsArray, defaultColor);
         }
 
         if (textureCoords != null) {
+	    textureCoords.rewind();
             if (textureCoords.hasArray()) {
                 buffer = textureCoords.array();
             } else {
-                buffer = new float[textureCoords.capacity()];
+                buffer = new float[textureCoords.limit()];
                 textureCoords.get(buffer);
             }
             textureCoordsArray = getMultiVectors(buffer);
@@ -280,7 +290,7 @@ public class Motor3D {
             if (indices.hasArray()) {
                 ind = indices.array();
             } else {
-                ind = new int[indices.capacity()];
+                ind = new int[indices.limit()];
                 indices.get(ind);
             }
             Vector3d[] va = new Vector3d[ind.length];
@@ -374,10 +384,10 @@ public class Motor3D {
         Vector3d[] textureCoordsArray = (Vector3d[]) arrays[2];
         Vector3d[] v;
         Color[] c;
-	Texture.Filter filter = Texture.Filter.NEAREST;
-	if (texture != null) {
-	    filter = texture.getMagnificationFilter();
-	}
+        Texture.Filter filter = Texture.Filter.NEAREST;
+        if (texture != null) {
+            filter = texture.getMagnificationFilter();
+        }
 
         switch (drawingMode) {
         case TRIANGLE_FAN :
