@@ -32,6 +32,12 @@ import org.scilab.forge.scirenderer.tranformations.Vector4d;
 public class Triangle extends ConvexObject {
 
     private static final Color[] COLORS = new Color[]{Color.BLACK, Color.BLACK, Color.BLACK};
+    private static Class IMAGEGRAPHICS2DCLASS;
+
+    static {
+	BufferedImage i = new BufferedImage(1, 1, BufferedImage.TYPE_INT_ARGB);
+	IMAGEGRAPHICS2DCLASS = i.createGraphics().getClass();
+    }
 
     private SpritedRectangle sprite;
     private BufferedImage image;
@@ -169,7 +175,9 @@ public class Triangle extends ConvexObject {
             Path2D contour = getProjectedContour();
             g2d.setColor(colors[0]);
             g2d.fill(contour);
-            //g2d.draw(contour);
+	    if (g2d.getClass() == IMAGEGRAPHICS2DCLASS) {
+		g2d.draw(contour);
+	    }
         } else {
             DrawTools.fillGouraud(g2d, this);
         }
