@@ -11,8 +11,10 @@
 
 package org.scilab.forge.scirenderer.texture;
 
+import org.scilab.forge.scirenderer.data.DataProvider;
+
 import java.awt.Dimension;
-import java.nio.Buffer;
+import java.nio.ByteBuffer;
 
 /**
  * @author Pierre Lando
@@ -29,7 +31,7 @@ public interface TextureDataProvider extends DataProvider<Texture> {
      * Data getter.
      * @return the data.
      */
-    Buffer getData();
+    ByteBuffer getData();
 
     /**
      * Sub-data getter.
@@ -39,5 +41,5 @@ public interface TextureDataProvider extends DataProvider<Texture> {
      * @param height rectangle height.
      * @return the data.
      */
-    Buffer getSubData(int x, int y, int width, int height);
+    ByteBuffer getSubData(int x, int y, int width, int height);
 }
