@@ -537,6 +537,7 @@ public final class TransformationFactory {
 
         private final double[] matrix;
         private final double[] inverseMatrix;
+        private final boolean isIdentity;
 
         /**
          * Default constructor.
@@ -566,12 +567,13 @@ public final class TransformationFactory {
                     (right + left) / 2, (top + bottom) / 2, -(near + far) / 2,  1
             };
 
+            isIdentity = ((left == -1) && (right == 1) && (bottom == -1) && (top == 1) && (far == -1) && (near == 1));
 
         }
 
         @Override
         public boolean isIdentity() {
-            return false; // TODO ?
+            return isIdentity;
         }
 
         @Override
@@ -625,6 +627,7 @@ public final class TransformationFactory {
 
         private final double[] matrix;
         private final double[] inverseMatrix;
+        private final boolean isIdentity;
 
         /**
          * Default constructor.
@@ -632,6 +635,7 @@ public final class TransformationFactory {
          * @param t2 first transformation.
          */
         public ProductTransformation(Transformation t1, Transformation t2) {
+            isIdentity = t1.isIdentity() && t2.isIdentity();
             matrix = multiply(t1.getMatrix(), t2.getMatrix());
 
             // TODO : inverse 'matrix' instead.
@@ -640,8 +644,7 @@ public final class TransformationFactory {
 
         @Override
         public boolean isIdentity() {
-            // TODO : test if we have identity here.
-            return false;
+            return isIdentity;
         }
 
         @Override
